@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     AccessControlRuleEffectType,
@@ -229,14 +229,14 @@ _OptionalCreateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
     {
         "ClientToken": str,
         "Description": str,
-        "DeviceTypes": List[str],
-        "NotDeviceTypes": List[str],
-        "DeviceModels": List[str],
-        "NotDeviceModels": List[str],
-        "DeviceOperatingSystems": List[str],
-        "NotDeviceOperatingSystems": List[str],
-        "DeviceUserAgents": List[str],
-        "NotDeviceUserAgents": List[str],
+        "DeviceTypes": Sequence[str],
+        "NotDeviceTypes": Sequence[str],
+        "DeviceModels": Sequence[str],
+        "NotDeviceModels": Sequence[str],
+        "DeviceOperatingSystems": Sequence[str],
+        "NotDeviceOperatingSystems": Sequence[str],
+        "DeviceUserAgents": Sequence[str],
+        "NotDeviceUserAgents": Sequence[str],
     },
     total=False,
 )
@@ -268,7 +268,7 @@ _OptionalCreateOrganizationRequestRequestTypeDef = TypedDict(
     {
         "DirectoryId": str,
         "ClientToken": str,
-        "Domains": List["DomainTypeDef"],
+        "Domains": Sequence["DomainTypeDef"],
         "KmsKeyArn": str,
         "EnableInteroperability": bool,
     },
@@ -1127,12 +1127,12 @@ _RequiredPutAccessControlRuleRequestRequestTypeDef = TypedDict(
 _OptionalPutAccessControlRuleRequestRequestTypeDef = TypedDict(
     "_OptionalPutAccessControlRuleRequestRequestTypeDef",
     {
-        "IpRanges": List[str],
-        "NotIpRanges": List[str],
-        "Actions": List[str],
-        "NotActions": List[str],
-        "UserIds": List[str],
-        "NotUserIds": List[str],
+        "IpRanges": Sequence[str],
+        "NotIpRanges": Sequence[str],
+        "Actions": Sequence[str],
+        "NotActions": Sequence[str],
+        "UserIds": Sequence[str],
+        "NotUserIds": Sequence[str],
     },
     total=False,
 )
@@ -1151,7 +1151,7 @@ PutMailboxPermissionsRequestRequestTypeDef = TypedDict(
         "OrganizationId": str,
         "EntityId": str,
         "GranteeId": str,
-        "PermissionValues": List[PermissionTypeType],
+        "PermissionValues": Sequence[PermissionTypeType],
     },
 )
 
@@ -1160,7 +1160,7 @@ _RequiredPutRetentionPolicyRequestRequestTypeDef = TypedDict(
     {
         "OrganizationId": str,
         "Name": str,
-        "FolderConfigurations": List["FolderConfigurationTypeDef"],
+        "FolderConfigurations": Sequence["FolderConfigurationTypeDef"],
     },
 )
 _OptionalPutRetentionPolicyRequestRequestTypeDef = TypedDict(
@@ -1263,7 +1263,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1279,7 +1279,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1305,14 +1305,14 @@ _OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateMobileDeviceAccessRuleRequestRequestTypeDef",
     {
         "Description": str,
-        "DeviceTypes": List[str],
-        "NotDeviceTypes": List[str],
-        "DeviceModels": List[str],
-        "NotDeviceModels": List[str],
-        "DeviceOperatingSystems": List[str],
-        "NotDeviceOperatingSystems": List[str],
-        "DeviceUserAgents": List[str],
-        "NotDeviceUserAgents": List[str],
+        "DeviceTypes": Sequence[str],
+        "NotDeviceTypes": Sequence[str],
+        "DeviceModels": Sequence[str],
+        "NotDeviceModels": Sequence[str],
+        "DeviceOperatingSystems": Sequence[str],
+        "NotDeviceOperatingSystems": Sequence[str],
+        "DeviceUserAgents": Sequence[str],
+        "NotDeviceUserAgents": Sequence[str],
     },
     total=False,
 )
